==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/id.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Berikan hak akses",
    "Error configuring OAuth2" : "Kesalahan mengkonfigurasi OAuth2",
    "Generate keys" : "Hasilkan kunci",
    "Error generating key pair" : "Kesalahan saat menghasilkan pasangan kunci",
    "Invalid backend or authentication mechanism class" : "Beckend atau kelas mekanisme otentikasi salah.",
    "Invalid mount point" : "Mount point salah",
    "Objectstore forbidden" : "Objectstore terlarang",
    "Invalid storage backend \"%s\"" : "Backend penyimpanan \"%s\" salah",
    "Not permitted to use backend \"%s\"" : "Tidak diizinkan menggunakan backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Tidak diizinkan menggunakan mekanisme otentikasi \"%s\"",
    "Unsatisfied backend parameters" : "Parameter backend tidak lengkap",
    "Unsatisfied authentication mechanism parameters" : "Parameter mekanisme otentikasi tidak lengkap",
    "Insufficient data: %s" : "Data tidak cukup: %s",
    "%s" : "%s",
    "Access key" : "Kunci akses",
    "Secret key" : "Kunci rahasia",
    "Builtin" : "Internal",
    "None" : "Tidak ada",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "Login" : "Masuk",
    "Password" : "Kata sandi",
    "Tenant name" : "Nama tenant",
    "Identity endpoint URL" : "Identitas URL akhir",
    "Domain" : "Domain",
    "Rackspace" : "Rackspace",
    "API key" : "Kunci API",
    "Global credentials" : "Kata sandi Global",
    "Log-in credentials, save in database" : "Kredensial masuk, simpan di basis data",
    "Log-in credentials, save in session" : "Kredensial masuk, simpan dalam sesi",
    "RSA public key" : "Kunci publik RSA",
    "Public key" : "Kunci Public",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Keranjang",
    "Hostname" : "Nama Host",
    "Port" : "Port",
    "Region" : "Daerah",
    "Enable SSL" : "Aktifkan SSL",
    "Enable Path Style" : "Aktifkan Gaya Path",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subfolder remote",
    "Secure https://" : "Secure https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Lokal",
    "Location" : "lokasi",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP dengan kunci rahasia masuk",
    "Share" : "Bagikan",
    "Show hidden files" : "Lihat berkas tersembunyi",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nama layanan",
    "Request timeout (seconds)" : "Minta waktu habis (detik)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Dukungan cURL di PHP tidak diaktifkan atau terpasang. Mengaitkan %s tidak memungkinkan. Harap tanyakan administrator sistem Anda untuk memasangnya.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Dukungan FTP di PHP tidak diaktifkan atau terpasang. Mengaitkan %s tidak memungkinkan. Harap tanya administrator sistem Anda untuk memasangnya.",
    "External storage" : "Penyimpanan eksternal",
    "Confirm" : "Konfirmasi",
    "External mount error" : "Kesalahan mount eksternal",
    "Storage type" : "Tipe penyimpanan",
    "Unknown" : "Tidak diketahui",
    "Scope" : "Skop",
    "Personal" : "Pribadi",
    "System" : "Sistem",
    "(Group)" : "(Grup)",
    "Compatibility with Mac NFD encoding (slow)" : "Kecocokan dengan pengkodean Mac NFD (lambat)",
    "Enable encryption" : "Aktifkan enkripsi",
    "Enable previews" : "Aktifkan pratinjau",
    "Enable sharing" : "Aktifkan pembagian",
    "Check for changes" : "Periksa perubahan",
    "Never" : "Jangan pernah",
    "Once every direct access" : "Setiap kali akses langsung",
    "Read only" : "Hanya baca",
    "Disconnect" : "Terputus",
    "Admin defined" : "Terdefinisi Admin",
    "Saved" : "Disimpan",
    "Save" : "Simpan",
    "Open documentation" : "Buka dokumentasi",
    "Folder name" : "Nama folder",
    "Authentication" : "Otentikasi",
    "Configuration" : "Konfigurasi",
    "Available for" : "Tersedia untuk",
    "Add storage" : "Tambahkan penyimpanan",
    "Advanced settings" : "Pengaturan Lanjutan",
    "Error configuring OAuth1" : "Kesalahan mengkonfigurasi OAuth1",
    "Please provide a valid app key and secret." : "Silakan berikan kunci dan kerahasiaan aplikasi yang benar.",
    "OAuth1" : "OAuth1",
    "App key" : "Kunci Apl",
    "App secret" : "Rahasia Apl",
    "Saving …" : "Menyimpan ..."
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/id.js <==
OC.L10N.register(
    "files_external",
    {
    "Invalid backend or authentication mechanism class" : "Beckend atau kelas mekanisme otentikasi salah.",
    "Invalid mount point" : "Mount point salah",
    "Objectstore forbidden" : "Objectstore terlarang",
    "Invalid storage backend \"%s\"" : "Backend penyimpanan \"%s\" salah",
    "Not permitted to use backend \"%s\"" : "Tidak diizinkan menggunakan backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Tidak diizinkan menggunakan mekanisme otentikasi \"%s\"",
    "Unsatisfied backend parameters" : "Parameter backend tidak lengkap",
    "Unsatisfied authentication mechanism parameters" : "Parameter mekanisme otentikasi tidak lengkap",
    "Insufficient data: %s" : "Data tidak cukup: %s",
    "Access key" : "Kunci akses",
    "Secret key" : "Kunci rahasia",
    "Builtin" : "Internal",
    "None" : "Tidak ada",
    "Login" : "Masuk",
    "Password" : "Kata sandi",
    "Tenant name" : "Nama tenant",
    "Identity endpoint URL" : "Identitas URL akhir",
    "Domain" : "Domain",
    "Rackspace" : "Rackspace",
    "API key" : "Kunci API",
    "Global credentials" : "Kata sandi Global",
    "Log-in credentials, save in database" : "Kredensial masuk, simpan di basis data",
    "Log-in credentials, save in session" : "Kredensial masuk, simpan dalam sesi",
    "RSA public key" : "Kunci publik RSA",
    "Public key" : "Kunci Public",
    "Bucket" : "Keranjang",
    "Hostname" : "Nama Host",
    "Port" : "Port",
    "Region" : "Daerah",
    "Enable SSL" : "Aktifkan SSL",
    "Enable Path Style" : "Aktifkan Gaya Path",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subfolder remote",
    "Secure https://" : "Secure https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Lokal",
    "Location" : "lokasi",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP dengan kunci rahasia masuk",
    "Share" : "Bagikan",
    "Show hidden files" : "Lihat berkas tersembunyi",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nama layanan",
    "Request timeout (seconds)" : "Minta waktu habis (detik)",
    "External storage" : "Penyimpanan eksternal",
    "Add storage" : "Tambahkan penyimpanan",
    "Folder name" : "Nama folder",
    "Authentication" : "Otentikasi",
    "Cancel" : "Cancel",
    "Edit" : "Sunting",
    "Create" : "Buat",
    "Never" : "Jangan pernah",
    "Once every direct access" : "Setiap kali akses langsung",
    "Read only" : "Hanya baca",
    "Enable previews" : "Aktifkan pratinjau",
    "Enable sharing" : "Aktifkan pembagian",
    "Enable encryption" : "Aktifkan enkripsi",
    "Compatibility with Mac NFD encoding (slow)" : "Kecocokan dengan pengkodean Mac NFD (lambat)",
    "External storages" : "Penyimpanan Eksternal",
    "Actions" : "Tindakan",
    "Delete" : "Hapus",
    "Saved" : "Disimpan",
    "Error generating key pair" : "Kesalahan saat menghasilkan pasangan kunci",
    "Generate keys" : "Hasilkan kunci",
    "Confirm" : "Konfirmasi",
    "Saving …" : "Menyimpan …",
    "Save" : "Simpan",
    "Open in Files" : "Buka di File",
    "External mount error" : "Kesalahan mount eksternal",
    "Storage type" : "Tipe penyimpanan",
    "Unknown" : "Tidak diketahui",
    "Scope" : "Skop",
    "Personal" : "Pribadi",
    "System" : "Sistem",
    "Connected" : "Tersambung",
    "Error" : "Galat",
    "Grant access" : "Berikan hak akses",
    "Error configuring OAuth1" : "Kesalahan mengkonfigurasi OAuth1",
    "Please provide a valid app key and secret." : "Silakan berikan kunci dan kerahasiaan aplikasi yang benar.",
    "Error configuring OAuth2" : "Kesalahan mengkonfigurasi OAuth2",
    "%s" : "%s",
    "OAuth1" : "OAuth1",
    "App key" : "Kunci Apl",
    "App secret" : "Rahasia Apl",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Dukungan cURL di PHP tidak diaktifkan atau terpasang. Mengaitkan %s tidak memungkinkan. Harap tanyakan administrator sistem Anda untuk memasangnya.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Dukungan FTP di PHP tidak diaktifkan atau terpasang. Mengaitkan %s tidak memungkinkan. Harap tanya administrator sistem Anda untuk memasangnya.",
    "(Group)" : "(Grup)",
    "Check for changes" : "Periksa perubahan",
    "Disconnect" : "Terputus",
    "Admin defined" : "Terdefinisi Admin",
    "Saving …" : "Menyimpan ...",
    "Open documentation" : "Buka dokumentasi",
    "Configuration" : "Konfigurasi",
    "Available for" : "Tersedia untuk",
    "Advanced settings" : "Pengaturan Lanjutan"
},
"nplurals=1; plural=0;");
